@@ -405,10 +405,64 @@ def get_new_share(htsc_code=None, book_start_date_online=None, listing_date=None
     return result
 
 
-# 债券基础信息
-def get_bond_info(htsc_codes=None, secu_category_code=None, listing_date=None, issue_start_date=None, end_date=None):
+# 日行情接口
+def get_daily_basic(htsc_code=None, trading_day=None):
     '''
-    :param htsc_codes: 华泰证券ID
+    :param htsc_code: 华泰证券ID
+    :param trading_day: 交易日期
+    :return: pandas.DataFrame
+    '''
+
+    if htsc_code:
+        if not isinstance(htsc_code, str):
+            return "htsc_code format is not str"
+
+    if trading_day:
+        if isinstance(trading_day, list):
+            if len(trading_day) > 2:
+                return "trading_day format is not [start_date, end_date]"
+            if len(trading_day) == 1:
+                trading_day = [trading_day[0], trading_day[0]]
+            if not isinstance(trading_day[0], datetime) or not isinstance(trading_day[1], datetime):
+                return "start_date,end_date format is not datetime"
+        else:
+            return "trading_day format is not list"
+
+    result = get_daily_basic_handle(htsc_code, trading_day)
+    return result
+
+
+# 股票行情指标接口
+def get_stock_valuation(htsc_code=None, trading_day=None):
+    '''
+    :param htsc_code: 华泰证券ID
+    :param trading_day: 交易日期
+    :return: pandas.DataFrame
+    '''
+
+    if htsc_code:
+        if not isinstance(htsc_code, str):
+            return "htsc_code format is not str"
+
+    if trading_day:
+        if isinstance(trading_day, list):
+            if len(trading_day) > 2:
+                return "trading_day format is not [start_date, end_date]"
+            if len(trading_day) == 1:
+                trading_day = [trading_day[0], trading_day[0]]
+            if not isinstance(trading_day[0], datetime) or not isinstance(trading_day[1], datetime):
+                return "start_date,end_date format is not datetime"
+        else:
+            return "trading_day format is not list"
+
+    result = get_stock_valuation_handle(htsc_code, trading_day)
+    return result
+
+
+# 债券基础信息
+def get_bond_info(htsc_code=None, secu_category_code=None, listing_date=None, issue_start_date=None, end_date=None):
+    '''
+    :param htsc_code: 华泰证券ID
     :param secu_category_code: 证券类别代码（细分）
                                 1    1301    国债
                                 2    1302    央行票据
@@ -469,7 +523,7 @@ def get_bond_info(htsc_codes=None, secu_category_code=None, listing_date=None, i
         else:
             return "end_date format is not list"
 
-    result = get_bond_info_handle(htsc_codes, secu_category_code, listing_date, issue_start_date, end_date)
+    result = get_bond_info_handle(htsc_code, secu_category_code, listing_date, issue_start_date, end_date)
     return result
 
 
